@@ -74,7 +74,6 @@ static void atexit_fun()
 {
     if(mis_raw_mode()) {
         mendwin();
-        //mreset_tty();
     }
 }
 
@@ -374,6 +373,8 @@ int main(int argc, char* argv[])
         return rcode;
     }
 
+    setenv("SAPHIRE_INTERACTIVE", "1", 1);
+
 #if !defined(ENABLE_READLINE)
     fprintf(stderr, "if you use saphire as interactive shell, use sash command instead\n");
     for(i=0; i<vector_size(argv2); i++) {
@@ -383,6 +384,8 @@ int main(int argc, char* argv[])
     return 0;
 #else
     /// インタラクティブシェル開始 ///
+    mreset_tty();   // 一応端末リセット
+
     mcurses_init(code);
 
     saphire_set_signal();
@@ -493,12 +496,12 @@ int main(int argc, char* argv[])
     saphire_final();
     mcurses_final();
 
+    mreset_tty();   // 一応端末リセット
+
     /// ヒストリーを書き込む ///
     if(histfile) {
         write_history(histfile);
     }
-    
-    mreset_tty();
 
     for(i=0; i<vector_size(argv2); i++) {
         string_delete(vector_item(argv2, i));
