@@ -16,7 +16,7 @@ enum eCommandKind {
     kChomp, kSubstr, kEval, kFg, kBg, kCpg,
     kJobs, kRehash, kKanjiCode, kLineField, kVar, kGlobal,
     kCalc, kExport, kPrint,  kPuts, kLoad, 
-    kWhile, kBreak, kExit, kIf, kSplit, kX, kJoin, kLines, kRows,
+    kWhile, kBreak, kExit, kIf, kSplit, kX, kJoin, kSelect, kLines, kRows,
     kAryNew, kAryAdd, kAryErase, kAryClear, 
     kHashNew, kHashAdd, kHashErase, kHashClear, kMatch, kScan, kErase, kPos, kSub,
     kRead, 
@@ -146,10 +146,12 @@ extern hash_obj* gFWriteBuffers;
     // ϥեǥץֹʸ
     // ƤϽ񤭹ե
 
+#if defined(__LINUX__) || defined(__DARWIN__) || defined(__FREEBSD__)
 extern int gMsgId;
     // å塼
     // fork˿ƥץȻҥץ̿˻Ȥ
     // (ץ롼פѤä)
+#endif
 
 extern hash_obj* gInnerCommands;
     // Ͽޥ
