@@ -55,7 +55,7 @@ char* gStatmentKindStrs[kCommand+1] = {
     "export", "print",  "puts",
     "load",
     "while", "break", "exit", "if", "split", 
-    "x", "join", "lines", "rows",
+    "x", "join", "select", "lines", "rows",
     "ary_new", "ary_add", "ary_erase", "ary_clear", 
     "hash_new", "hash_add", "hash_erase", "hash_clear",
     "match", "scan", "erase", "pos", "sub",  
@@ -176,10 +176,12 @@ hash_obj* gFWriteBuffers;
     // キーはファイルディスクリプタ番号の文字列
     // 内容は書き込んだファイルの内容
 
+#if defined(__LINUX__) || defined(__DARWIN__) || defined(__FREEBSD__)
 int gMsgId;
     // メッセージキュー
     // fork後に親プロセスと子プロセスの通信に使われる
     // (プロセスグループが変わった場合に)
+#endif
 
 hash_obj* gInnerCommands;
     // 外部登録の内部コマンド
@@ -884,7 +886,8 @@ void saphire_set_signal_optc()
 
     memset(&sa, 0, sizeof(sa));
     sa.sa_flags = SA_SIGINFO;
-    sa.sa_handler = SIG_IGN; //sig_int_optc;
+    sa.sa_handler = sig_int_optc;
+    //sa.sa_handler = SIG_IGN; //sig_int_optc;
     if(sigaction(SIGINT, &sa, NULL) < 0) {
         perror("sigaction2");
         exit(1);
@@ -2731,7 +2734,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "1.2.4", 1);
+    setenv("SAPHIRE_VERSION", "1.2.8", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
@@ -2769,11 +2772,14 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
     gDirStack = VECTOR_NEW(10);
     gErrMsg = STRING_NEW("");
 
+#if defined(__LINUX__) || defined(__DARWIN__) || defined(__FREEBSD__)
     gMsgId = msgget((key_t)1234, 0666 | IPC_CREAT);
     if(gMsgId < 0) {
         fprintf(stderr, "msgget failed\n");
         exit(EXIT_FAILURE);
     }
+#endif
+
 
 //    saphire_rehash();
 
@@ -2963,9 +2969,11 @@ void saphire_final()
     }
     vector_delete(gStrayCProgs);
 
+#if defined(__LINUX__) || defined(__DARWIN__) || defined(__FREEBSD__)
     if(msgctl(gMsgId, IPC_RMID, 0) == -1) {
         fprintf(stderr, "msgctl(IPC_RMID) failed\n");
     }
+#endif
 
     it = hash_loop_begin(gInnerCommands);
     while(it != NULL) {
